==> openshift-model-miscellaneous-6.6.0-sources.jar: io/fabric8/openshift/api/model/miscellaneous/imageregistry/operator/v1/ImageRegistryConfigStorageFluent.java <==
package io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface ImageRegistryConfigStorageFluent<A extends ImageRegistryConfigStorageFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildAzure instead.
   * @return The buildable object.
   */
  @Deprecated
  public ImageRegistryConfigStorageAzure getAzure();
  public ImageRegistryConfigStorageAzure buildAzure();
  public A withAzure(ImageRegistryConfigStorageAzure azure);
  public Boolean hasAzure();
  public A withNewAzure(String accountName,String cloudName,String container);
  public ImageRegistryConfigStorageFluent.AzureNested<A> withNewAzure();
  public ImageRegistryConfigStorageFluent.AzureNested<A> withNewAzureLike(ImageRegistryConfigStorageAzure item);
  public ImageRegistryConfigStorageFluent.AzureNested<A> editAzure();
  public ImageRegistryConfigStorageFluent.AzureNested<A> editOrNewAzure();
  public ImageRegistryConfigStorageFluent.AzureNested<A> editOrNewAzureLike(ImageRegistryConfigStorageAzure item);
  
  /**
   * This method has been deprecated, please use method buildEmptyDir instead.
   * @return The buildable object.
   */
  @Deprecated
  public ImageRegistryConfigStorageEmptyDir getEmptyDir();
  public ImageRegistryConfigStorageEmptyDir buildEmptyDir();
  public A withEmptyDir(ImageRegistryConfigStorageEmptyDir emptyDir);
  public Boolean hasEmptyDir();
  public ImageRegistryConfigStorageFluent.EmptyDirNested<A> withNewEmptyDir();
  public ImageRegistryConfigStorageFluent.EmptyDirNested<A> withNewEmptyDirLike(ImageRegistryConfigStorageEmptyDir item);
  public ImageRegistryConfigStorageFluent.EmptyDirNested<A> editEmptyDir();
  public ImageRegistryConfigStorageFluent.EmptyDirNested<A> editOrNewEmptyDir();
  public ImageRegistryConfigStorageFluent.EmptyDirNested<A> editOrNewEmptyDirLike(ImageRegistryConfigStorageEmptyDir item);
  
  /**
   * This method has been deprecated, please use method buildGcs instead.
   * @return The buildable object.
   */
  @Deprecated
  public ImageRegistryConfigStorageGCS getGcs();
  public ImageRegistryConfigStorageGCS buildGcs();
  public A withGcs(ImageRegistryConfigStorageGCS gcs);
  public Boolean hasGcs();
  public A withNewGcs(String bucket,String keyID,String projectID,String region);
  public ImageRegistryConfigStorageFluent.GcsNested<A> withNewGcs();
  public ImageRegistryConfigStorageFluent.GcsNested<A> withNewGcsLike(ImageRegistryConfigStorageGCS item);
  public ImageRegistryConfigStorageFluent.GcsNested<A> editGcs();
  public ImageRegistryConfigStorageFluent.GcsNested<A> editOrNewGcs();
  public ImageRegistryConfigStorageFluent.GcsNested<A> editOrNewGcsLike(ImageRegistryConfigStorageGCS item);
  
  /**
   * This method has been deprecated, please use method buildIbmcos instead.
   * @return The buildable object.
   */
  @Deprecated
  public ImageRegistryConfigStorageIBMCOS getIbmcos();
  public ImageRegistryConfigStorageIBMCOS buildIbmcos();
  public A withIbmcos(ImageRegistryConfigStorageIBMCOS ibmcos);
  public Boolean hasIbmcos();
  public A withNewIbmcos(String bucket,String location,String resourceGroupName,String resourceKeyCRN,String serviceInstanceCRN);
  public ImageRegistryConfigStorageFluent.IbmcosNested<A> withNewIbmcos();
  public ImageRegistryConfigStorageFluent.IbmcosNested<A> withNewIbmcosLike(ImageRegistryConfigStorageIBMCOS item);
  public ImageRegistryConfigStorageFluent.IbmcosNested<A> editIbmcos();
  public ImageRegistryConfigStorageFluent.IbmcosNested<A> editOrNewIbmcos();
  public ImageRegistryConfigStorageFluent.IbmcosNested<A> editOrNewIbmcosLike(ImageRegistryConfigStorageIBMCOS item);
  public String getManagementState();
  public A withManagementState(String managementState);
  public Boolean hasManagementState();
  
  /**
   * This method has been deprecated, please use method buildPvc instead.
   * @return The buildable object.
   */
  @Deprecated
  public ImageRegistryConfigStoragePVC getPvc();
  public ImageRegistryConfigStoragePVC buildPvc();
  public A withPvc(ImageRegistryConfigStoragePVC pvc);
  public Boolean hasPvc();
  public A withNewPvc(String claim);
  public ImageRegistryConfigStorageFluent.PvcNested<A> withNewPvc();
  public ImageRegistryConfigStorageFluent.PvcNested<A> withNewPvcLike(ImageRegistryConfigStoragePVC item);
  public ImageRegistryConfigStorageFluent.PvcNested<A> editPvc();
  public ImageRegistryConfigStorageFluent.PvcNested<A> editOrNewPvc();
  public ImageRegistryConfigStorageFluent.PvcNested<A> editOrNewPvcLike(ImageRegistryConfigStoragePVC item);
  
  /**
   * This method has been deprecated, please use method buildS3 instead.
   * @return The buildable object.
   */
  @Deprecated
  public ImageRegistryConfigStorageS3 getS3();
  public ImageRegistryConfigStorageS3 buildS3();
  public A withS3(ImageRegistryConfigStorageS3 s3);
  public Boolean hasS3();
  public ImageRegistryConfigStorageFluent.S3Nested<A> withNewS3();
  public ImageRegistryConfigStorageFluent.S3Nested<A> withNewS3Like(ImageRegistryConfigStorageS3 item);
  public ImageRegistryConfigStorageFluent.S3Nested<A> editS3();
  public ImageRegistryConfigStorageFluent.S3Nested<A> editOrNewS3();
  public ImageRegistryConfigStorageFluent.S3Nested<A> editOrNewS3Like(ImageRegistryConfigStorageS3 item);
  
  /**
   * This method has been deprecated, please use method buildSwift instead.
   * @return The buildable object.
   */
  @Deprecated
  public ImageRegistryConfigStorageSwift getSwift();
  public ImageRegistryConfigStorageSwift buildSwift();
  public A withSwift(ImageRegistryConfigStorageSwift swift);
  public Boolean hasSwift();
  public ImageRegistryConfigStorageFluent.SwiftNested<A> withNewSwift();
  public ImageRegistryConfigStorageFluent.SwiftNested<A> withNewSwiftLike(ImageRegistryConfigStorageSwift item);
  public ImageRegistryConfigStorageFluent.SwiftNested<A> editSwift();
  public ImageRegistryConfigStorageFluent.SwiftNested<A> editOrNewSwift();
  public ImageRegistryConfigStorageFluent.SwiftNested<A> editOrNewSwiftLike(ImageRegistryConfigStorageSwift item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface AzureNested<N> extends Nested<N>,ImageRegistryConfigStorageAzureFluent<ImageRegistryConfigStorageFluent.AzureNested<N>>{
    public N and();
    public N endAzure();
    
  }
  public interface EmptyDirNested<N> extends Nested<N>,ImageRegistryConfigStorageEmptyDirFluent<ImageRegistryConfigStorageFluent.EmptyDirNested<N>>{
    public N and();
    public N endEmptyDir();
    
  }
  public interface GcsNested<N> extends Nested<N>,ImageRegistryConfigStorageGCSFluent<ImageRegistryConfigStorageFluent.GcsNested<N>>{
    public N and();
    public N endGcs();
    
  }
  public interface IbmcosNested<N> extends Nested<N>,ImageRegistryConfigStorageIBMCOSFluent<ImageRegistryConfigStorageFluent.IbmcosNested<N>>{
    public N and();
    public N endIbmcos();
    
  }
  public interface PvcNested<N> extends Nested<N>,ImageRegistryConfigStoragePVCFluent<ImageRegistryConfigStorageFluent.PvcNested<N>>{
    public N and();
    public N endPvc();
    
  }
  public interface S3Nested<N> extends Nested<N>,ImageRegistryConfigStorageS3Fluent<ImageRegistryConfigStorageFluent.S3Nested<N>>{
    public N and();
    public N endS3();
    
  }
  public interface SwiftNested<N> extends Nested<N>,ImageRegistryConfigStorageSwiftFluent<ImageRegistryConfigStorageFluent.SwiftNested<N>>{
    public N and();
    public N endSwift();
    
  }
  
}

==> openshift-model-miscellaneous-6.7.2-sources.jar: io/fabric8/openshift/api/model/miscellaneous/imageregistry/operator/v1/ImageRegistryConfigStorageFluent.java <==
package io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface ImageRegistryConfigStorageFluent<A extends ImageRegistryConfigStorageFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildAzure instead.
   * @return The buildable object.
   */
  @Deprecated
  public ImageRegistryConfigStorageAzure getAzure();
  public ImageRegistryConfigStorageAzure buildAzure();
  public A withAzure(ImageRegistryConfigStorageAzure azure);
  public Boolean hasAzure();
  public A withNewAzure(String accountName,String cloudName,String container);
  public ImageRegistryConfigStorageFluent.AzureNested<A> withNewAzure();
  public ImageRegistryConfigStorageFluent.AzureNested<A> withNewAzureLike(ImageRegistryConfigStorageAzure item);
  public ImageRegistryConfigStorageFluent.AzureNested<A> editAzure();
  public ImageRegistryConfigStorageFluent.AzureNested<A> editOrNewAzure();
  public ImageRegistryConfigStorageFluent.AzureNested<A> editOrNewAzureLike(ImageRegistryConfigStorageAzure item);
  
  /**
   * This method has been deprecated, please use method buildEmptyDir instead.
   * @return The buildable object.
   */
  @Deprecated
  public ImageRegistryConfigStorageEmptyDir getEmptyDir();
  public ImageRegistryConfigStorageEmptyDir buildEmptyDir();
  public A withEmptyDir(ImageRegistryConfigStorageEmptyDir emptyDir);
  public Boolean hasEmptyDir();
  public ImageRegistryConfigStorageFluent.EmptyDirNested<A> withNewEmptyDir();
  public ImageRegistryConfigStorageFluent.EmptyDirNested<A> withNewEmptyDirLike(ImageRegistryConfigStorageEmptyDir item);
  public ImageRegistryConfigStorageFluent.EmptyDirNested<A> editEmptyDir();
  public ImageRegistryConfigStorageFluent.EmptyDirNested<A> editOrNewEmptyDir();
  public ImageRegistryConfigStorageFluent.EmptyDirNested<A> editOrNewEmptyDirLike(ImageRegistryConfigStorageEmptyDir item);
  
  /**
   * This method has been deprecated, please use method buildGcs instead.
   * @return The buildable object.
   */
  @Deprecated
  public ImageRegistryConfigStorageGCS getGcs();
  public ImageRegistryConfigStorageGCS buildGcs();
  public A withGcs(ImageRegistryConfigStorageGCS gcs);
  public Boolean hasGcs();
  public A withNewGcs(String bucket,String keyID,String projectID,String region);
  public ImageRegistryConfigStorageFluent.GcsNested<A> withNewGcs();
  public ImageRegistryConfigStorageFluent.GcsNested<A> withNewGcsLike(ImageRegistryConfigStorageGCS item);
  public ImageRegistryConfigStorageFluent.GcsNested<A> editGcs();
  public ImageRegistryConfigStorageFluent.GcsNested<A> editOrNewGcs();
  public ImageRegistryConfigStorageFluent.GcsNested<A> editOrNewGcsLike(ImageRegistryConfigStorageGCS item);
  
  /**
   * This method has been deprecated, please use method buildIbmcos instead.
   * @return The buildable object.
   */
  @Deprecated
  public ImageRegistryConfigStorageIBMCOS getIbmcos();
  public ImageRegistryConfigStorageIBMCOS buildIbmcos();
  public A withIbmcos(ImageRegistryConfigStorageIBMCOS ibmcos);
  public Boolean hasIbmcos();
  public A withNewIbmcos(String bucket,String location,String resourceGroupName,String resourceKeyCRN,String serviceInstanceCRN);
  public ImageRegistryConfigStorageFluent.IbmcosNested<A> withNewIbmcos();
  public ImageRegistryConfigStorageFluent.IbmcosNested<A> withNewIbmcosLike(ImageRegistryConfigStorageIBMCOS item);
  public ImageRegistryConfigStorageFluent.IbmcosNested<A> editIbmcos();
  public ImageRegistryConfigStorageFluent.IbmcosNested<A> editOrNewIbmcos();
  public ImageRegistryConfigStorageFluent.IbmcosNested<A> editOrNewIbmcosLike(ImageRegistryConfigStorageIBMCOS item);
  public String getManagementState();
  public A withManagementState(String managementState);
  public Boolean hasManagementState();
  
  /**
   * This method has been deprecated, please use method buildPvc instead.
   * @return The buildable object.
   */
  @Deprecated
  public ImageRegistryConfigStoragePVC getPvc();
  public ImageRegistryConfigStoragePVC buildPvc();
  public A withPvc(ImageRegistryConfigStoragePVC pvc);
  public Boolean hasPvc();
  public A withNewPvc(String claim);
  public ImageRegistryConfigStorageFluent.PvcNested<A> withNewPvc();
  public ImageRegistryConfigStorageFluent.PvcNested<A> withNewPvcLike(ImageRegistryConfigStoragePVC item);
  public ImageRegistryConfigStorageFluent.PvcNested<A> editPvc();
  public ImageRegistryConfigStorageFluent.PvcNested<A> editOrNewPvc();
  public ImageRegistryConfigStorageFluent.PvcNested<A> editOrNewPvcLike(ImageRegistryConfigStoragePVC item);
  
  /**
   * This method has been deprecated, please use method buildS3 instead.
   * @return The buildable object.
   */
  @Deprecated
  public ImageRegistryConfigStorageS3 getS3();
  public ImageRegistryConfigStorageS3 buildS3();
  public A withS3(ImageRegistryConfigStorageS3 s3);
  public Boolean hasS3();
  public ImageRegistryConfigStorageFluent.S3Nested<A> withNewS3();
  public ImageRegistryConfigStorageFluent.S3Nested<A> withNewS3Like(ImageRegistryConfigStorageS3 item);
  public ImageRegistryConfigStorageFluent.S3Nested<A> editS3();
  public ImageRegistryConfigStorageFluent.S3Nested<A> editOrNewS3();
  public ImageRegistryConfigStorageFluent.S3Nested<A> editOrNewS3Like(ImageRegistryConfigStorageS3 item);
  
  /**
   * This method has been deprecated, please use method buildSwift instead.
   * @return The buildable object.
   */
  @Deprecated
  public ImageRegistryConfigStorageSwift getSwift();
  public ImageRegistryConfigStorageSwift buildSwift();
  public A withSwift(ImageRegistryConfigStorageSwift swift);
  public Boolean hasSwift();
  public ImageRegistryConfigStorageFluent.SwiftNested<A> withNewSwift();
  public ImageRegistryConfigStorageFluent.SwiftNested<A> withNewSwiftLike(ImageRegistryConfigStorageSwift item);
  public ImageRegistryConfigStorageFluent.SwiftNested<A> editSwift();
  public ImageRegistryConfigStorageFluent.SwiftNested<A> editOrNewSwift();
  public ImageRegistryConfigStorageFluent.SwiftNested<A> editOrNewSwiftLike(ImageRegistryConfigStorageSwift item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface AzureNested<N> extends Nested<N>,ImageRegistryConfigStorageAzureFluent<ImageRegistryConfigStorageFluent.AzureNested<N>>{
    public N and();
    public N endAzure();
    
  }
  public interface EmptyDirNested<N> extends Nested<N>,ImageRegistryConfigStorageEmptyDirFluent<ImageRegistryConfigStorageFluent.EmptyDirNested<N>>{
    public N and();
    public N endEmptyDir();
    
  }
  public interface GcsNested<N> extends Nested<N>,ImageRegistryConfigStorageGCSFluent<ImageRegistryConfigStorageFluent.GcsNested<N>>{
    public N and();
    public N endGcs();
    
  }
  public interface IbmcosNested<N> extends Nested<N>,ImageRegistryConfigStorageIBMCOSFluent<ImageRegistryConfigStorageFluent.IbmcosNested<N>>{
    public N and();
    public N endIbmcos();
    
  }
  public interface PvcNested<N> extends Nested<N>,ImageRegistryConfigStoragePVCFluent<ImageRegistryConfigStorageFluent.PvcNested<N>>{
    public N and();
    public N endPvc();
    
  }
  public interface S3Nested<N> extends Nested<N>,ImageRegistryConfigStorageS3Fluent<ImageRegistryConfigStorageFluent.S3Nested<N>>{
    public N and();
    public N endS3();
    
  }
  public interface SwiftNested<N> extends Nested<N>,ImageRegistryConfigStorageSwiftFluent<ImageRegistryConfigStorageFluent.SwiftNested<N>>{
    public N and();
    public N endSwift();
    
  }
  
}
